<?php

namespace Drupal\commerce_quick_node_clone\Controller;

use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\commerce_product\Entity\Product;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\node\Controller\NodeController;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Returns responses for Quick Node Clone Node routes.
 */
class QuickNodeCloneNodeController extends NodeController {

  /**
   * Constructs a NodeController object.
   *
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter service.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
   *   The entity repository.
   */
  public function __construct(DateFormatterInterface $date_formatter, RendererInterface $renderer, EntityRepositoryInterface $entity_repository) {
    parent::__construct($date_formatter, $renderer, $entity_repository);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('date.formatter'),
      $container->get('renderer'),
      $container->get('entity.repository'),
    );
  }

  /**
   * Provides the node submission form.
   *
   * @param \Drupal\commerce_product\Entity\Product
   *   The node entity to clone.
   *
   * @return array
   *   A node submission form.
   */
  public function cloneNode(Product $node) {
    if (!empty($node)) {
      $duplicate = $node->createDuplicate();
      $duplicate->set('title', 'Clone of ' . $duplicate->label());
      $duplicate->set('changed', \Drupal::time()->getCurrentTime());
      $duplicate->save();
      $response = new RedirectResponse('/product/' . $duplicate->id() . '/edit');
      $response->send();
      return [];
    }
    else {
      throw new NotFoundHttpException();
    }
  }

}
